function [listeq]=auto_stage1(y,x,listeq,indx,indcte,firstelim,r00,rmod,alpha,eta,z)
 
// PURPOSE: starting from the variable whose index in indx is
// firstelim, find a path where: the less significant variable
// which does not make the specification tests calculated in
// test_func fails is successively withdrawn until :
// 1) either the withdrawn variables as a group has been
//   already encountered on another path
// 2) or all remaining variables are non significant or make
// the specification tests calculated in test_func fail
// ------------------------------------------------------------
// INPUT:
// * y = vector of the endogenous variable
// * x = matrix of the exogenous variables
// * listeq = the list containing all preceding paths and the
//   corresponding estimation results
// * index = the indexes of the x variables remaining at the
//   entry of the function
// * indcte = the booelan indicating the presence or the
//   absence of the constant in the regression
// * firstelim = the index of the first variable which is
//   withdrawn to begin the path
// * r00 = the results tlist for the regression containing all
//   exogenous variables whose index is in indx
// * rmod = a tlist defined by def_results
// * alpha = the simplification significance level
// * eta = a vector equal to the significance levels for the
//   specification tests
// * z = matrix of the compulsory variables (the ones that must
//   be in the regression whatever significance they have)
// ------------------------------------------------------------
// OUTPUT:
// * listeq = the entry list plus the path followed here and,
//   if it leads to a new model, the corresponding estimation
//   results
// ------------------------------------------------------------
// NOTES:
// * used by automatic()
// ------------------------------------------------------------
// Copyright: Eric Dubois 2002-2009
// http://dubois.ensae.net/grocer.html
 
 
// set initial values
endst1=%f
// endst1 is a boolean which becomes true when the path is stopped
previouspath=%f
// previouspath is a boolean which becomes true when the set
// of withdrawn variables becomes identical to one already
// encountered witdrawn one another path
nvarelim=1
path=[]
valpath=%f
// valpath is a boolean indicating that a new model has been
// discovered
nx=size(indx,1)
nz=size(z,2)
 
// withdraw the variable whose number has been given and
// estimate the corresponding model
indsuppr=indx(firstelim)
indx(firstelim)=[]
xpath=x(:,indx)
r=grocer_estim1(y,[z xpath],rmod)
 
 
[val,p]=test_func(r)
 
if (and(p >= eta)) then
// none of the specification tests fails, the path
// is a valid one; if it is not the case then the
// variable that has been eliminated at the entry of the function
// cannot be withdrawn
 
// intialize some paramaters of listeq useful for the comparison
// of the path with the current one
   npath=length(listeq)/3
   size_npath=[]
   for i=1:npath
      size_npath=[size_npath ; size(listeq(3*i-2),2)]
   end
   [gpath,indpath]=gsort(size_npath,'g','d')
 
   if npath ~= 0 then
   // create a matrix oldpath that collects all the previous
   // discovered paths
      oldpath=zeros(npath,gpath(1))
      for i=1:npath
         oldpath(i,1:gpath(i))=listeq(3*indpath(i)-2)
      end
   else
      oldpath=[]
   end
 
 
   path=indsuppr
 
   while ~endst1
   // search for an insignificant variable to withdraw
      [gpvalue,indpvalue]=gsort(r('pvalue')(nz+1:$),'g','d')
      nonsignif=size(indpvalue(gpvalue > alpha),1)
      nvarelim=nvarelim+1
 
      if nonsignif == 0 then
      // all variables are significant: no reduction is now possible
      // turn endst1 to true
         endst1=%t
 
      elseif nvarelim == nx then
         // there are no more variables in the model
         listeq($+1)=path
         listeq($+1)=[]
         listeq($+1)=[]
         return
 
      else
         n=1
         // start by removing the least significant variable
         indsuppr=indx(indpvalue(1))
         indx(indpvalue(1))=[]
         // fill xpath with the remaining variables in x
         xpath=x(:,indx)
         r=grocer_estim1(y,[z xpath],rmod)
         [val,p]=test_func(r)
 
         while (or(p < eta)) & n < nonsignif
         // one of the specification tests fails, re-introduce the removed
         // variable and try the next least-significant variable
 
            indx=[indx(1:indpvalue(n)-1) ; indsuppr ; indx(indpvalue(n):$)]
            n=n+1
            indsuppr=indx(indpvalue(n))
            indx(indpvalue(n))=[]
            xpath=x(:,indx)
            r=grocer_estim1(y,[z xpath],rmod)
            [val,p]=test_func(r)
 
         end
 
         if or(p<eta) then
         // specifiation tests are not passed for any remaining variable:
         // no reduction is now possible add again the removed variable
            indx=[indx(1:indpvalue(n)-1) ; indsuppr ; indx(indpvalue(n):$)]
            endst1=%t
         // the last estimation in the preceding loop is not valid
            xpath=x(:,indx)
            r=grocer_estim1(y,[z xpath],rmod)
            [val,p]=test_func(r)
 
         else
         // updates the path
            path=[path indsuppr]
            npathi=size(path,2)
            ordpath=gsort(path,'g','d')
            if npathi <= gpath(1) then
            // the new path has its length lower than the longest previous one:
            // check if the new one has not already been encountered
            // to that end compare the sorted path to the corresponding sorted
            // old paths
               for j=1:size(oldpath,1)
                  if ordpath == gsort(oldpath(j,1:npathi),'g','d')
                    //path already encoutered: stop there
                     listeq($+1)=path
                     listeq($+1)=[]
                     listeq($+1)=[]
                     return
                  end
               end
            end
         end
      end
   end
 
   // the process has discovered a new model; then update the list listed
   // fill all the fields in the results tlist r that have not been filled
   // for the sake of speed
 
   [indsort,ind0]=gsort(indx,'g','i')
   r('beta')=r('beta')([1:nz nz+ind0'])
   r('tstat')=r('tstat')([1:nz nz+ind0']')
   r('pvalue')=r('pvalue')([1:nz nz+ind0']')
   r('x')=r('x')(:,[1:nz nz+ind0'])
   listeq($+1)=path
   listeq($+1)=indsort
   prescte=or(nz+indsort == indcte)
   nvar=r('nvar')
   r('sige')=r('sigu')/(nobs-nvar)
   r('ser')=sqrt(r('sige'))
   r('yhat')=r('x')*r('beta')
   resid=r('resid')
   ediff = resid(2:nobs)-resid(1:nobs-1)
   dw = ediff'*ediff/r('sigu')
   // durbin-watson
 
   condindex=bkwols([z xpath])
 
   r('dw')=dw
   r('condindex')=condindex
   r('prescte')=prescte
 
   if prescte & nvar ~=1 then
      r=add_r2(r,r('sigu'),r('ym'),nobs,nvar)
   else
      r('prescte')=%f
   end
 
   r('spec_test')=[val p]
   r('namex')=[r00('namex')(1:nz) ; r00('namex')(nz+indsort)]
   r('aic')=log(r('sigu')/nobs)+r('nvar')*2/r('nobs')
   r('bic')=log(r('sigu')/nobs)+r('nvar')*log(r('nobs'))/r('nobs')
   r('hq')=log(r('sigu')/nobs)+r('nvar')*2*log(log(r('nobs')))/r('nobs')
   listeq($+1)=r
 
end
 
endfunction
