function [results,r_checks,nbmodst1,list1_2]=check_groups(results,y,z,groups_pval,gpvalue,indpvalue1_0,gam,eta,rmod,list1_2,nbmodst1,indcte)
 
// PURPOSE: estimate models with variables whose significance
// is greater than prespecified levels, whose strigency is
// increasing and stops whenever the model is not rejected
// against the stage 0 model or specification tests are
// rejected
// ------------------------------------------------------------
// REFERENCES:
// Krolzig, H.-M. and Hendry, D.F. (2001): "Computer Automation
//  of General-to-Specific Model Selection Procedures", Journal
// of Economic Dynamics and Control, 25 (6-7), 831-866.
// ------------------------------------------------------------
// INPUT:
// * results = an automatic tlist results
// * y = vector of the endogenous variable
// * z = matrix of the compulsory variables (the ones that must
//   be in the regression whatever significance they have)
// * x = matrix of the exogenous variables
// * groups_pval = a vector of significance levels ordered from
//   the lowest to the greatest
// * gpvalue = the vector of p-values from the previous
//  (stage 0) regression
// * indpvalue1_0 = the corresponding vector of indexes in the
//   list of initial variables
// * gam = the significance-level of F-tests
// * eta = a vector equal to the significance levels for the
//   specification tests
// * rmod = a tlist defined by def_results
// * list1_2 = the list of models selected before
// * nbmodst1 = the corresponding number of models
// * indcte = the booelan indicating the presence or the
//   absence of the constant in the regression
// ------------------------------------------------------------
// OUTPUT:
// * results = an automatic tlist results
// * r_checks = the first estimated model that is accepted
//   against the initial one or the last that passes the
//   specification tests
// * nbmodst1 = the number of models selected at the end of
//   stage 1
// * list1_2 = the list of models selected at the end of
//   stage 1
// ------------------------------------------------------------
// Copyright: Eric Dubois 2005
 
ind_check=find(gpvalue < groups_pval($))
if isempty(ind_check) then
// all variables are not significant even at the lowest level
   r_checks=[]
   results(1)($+1)='checking process'
   results('checking process model')=r_checks
   return
end
 
fp=0
i=1
p=0
nz=size(z,2)
nvar_0=size(gpvalue,1)
 
while ((fp < gam) | or(p < eta)) & (i <= size(groups_pval,1)) then
   ind_check=find(gpvalue < groups_pval(i))
   if ~isempty(ind_check) then
      indxf=gsort(indpvalue(ind_check(1):nvar_0),'g','i')
      xd=xpath(:,indxf)
      r_checks=ols1a(y,[z xd],rmod)
      r_checks('sige')=r_checks('sigu')/(r_checks('nobs')-r_checks('nvar'))
      [val,p]=test_func(r_checks)
      if ind_check(1) ~= 1 then
         [fstat,fp]=waldf0(r_checks,r1_0)
      else
         fp=1
      end
 
   end
   i=i+1
end
 
p$=string(groups_pval(i-1))
nvar=r_checks('nvar')
resid=r_checks('resid')
r_checks('ser')=sqrt(r_checks('sigu')/(nobs-nvar))
ediff = resid(2:nobs)-resid(1:nobs-1)
dw = ediff'*ediff/r_checks('sigu')
// durbin-watson
condindex=bkwols(xd)
prescte=or(indxf == indcte)
 
r_checks('dw')=dw
r_checks('condindex')=condindex
r_checks('prescte')=prescte
r_checks('namex')=[r1_0('namex')(1:nz) ; r1_0('namex')(nz+indxf)]
 
if prescte & nvar ~=1 then
// there is a constant and at least another exogenous
//  variable: R and Rbar make sense
   r_checks=add_r2(r_checks,r_checks('sigu'),r_checks('ym'),nobs,nvar)
else
   r_checks('prescte')=%f
end
 
r_checks('spec_test')=[val p]
r_checks(1)($+1)='indxf'
r_checks('indxf')=indxf
 
results(1)($+1)='checking process model'
results('checking process model')=r_checks
 
add_checks=%t
for i=1:nbmodst1
   if r_checks('indxf') == gsort(list1_2(3*i-1),'g','i') then
      add_checks=%f
   end
end
 
if add_checks then
   eliminated=[1:nvar_0]
   eliminated(indxf)=[]
   list1_2($+1)=['variables with t-probs intially > '+p$+' eliminated:' ; r1_0('namex')(eliminated)]
   list1_2($+1)=r_checks('indxf')
   list1_2($+1)=r_checks
   nbmodst1=nbmodst1+1
end
 
endfunction
 
