function [results]=nwest1a(y,x,results)
 
// PURPOSE: one of the numerous functions performing ordinary
// least squares: this one assumes that x et y are already a
// matrix, and a vector, that a result structure exists which
// can be filled and does not provide DW, R statistics
// ------------------------------------------------------------
// INPUT:
// * y = dependent variable vector (nobs x 1)
// * x = independent variables matrix (nobs x nvar)
// * results: an existing tlist of regression results
// ------------------------------------------------------------
// OUTPUT:
// a tlist with:
//        results('meth')  = 'ols'
//        results('beta')  = bhat
//        results('tstat') = t-stats
//        results('yhat')  = yhat
//        results('resid') = residuals
//        results('sige')  = e'*e/(n-k)
//        results('rsqr')  = rsquared
//        results('rbar')  = rbar-squared
//        results('dw')    = Durbin-Watson Statistic
//        results('nobs')  = nobs
//        results('nvar')  = nvars
//        results('y')     = y data vector
//        results('x')     = x data matrix
//
// ------------------------------------------------------------
// NOTES:
// used by automatic(), auto_stage0(),
// ------------------------------------------------------------
// Copyright: Eric Dubois 2009
// http://dubois.ensae.net/grocer.html
 
// adapted from:
// James P. LeSage, Dept of Economics
// University of Toledo
// 2801 W. Bancroft St,
// Toledo, OH 43606
// jlesage@spatial-econometrics.com
 
[nobs,nvar]=size(x)
 
[bet,xpxi]=ols0(y,x)
yhat = x*bet
resid = y-yhat
sigu =resid'*resid
 
emat=ones(nvar,1) .*. resid'
 
hhat=emat .* x'
xuux=hhat(:,1:nobs)*hhat(:,1:nobs)'
 
win=results('win')
for i=1:win
   zi=hhat(:,(i+1):nobs)*hhat(:,1:nobs-i)'
   gi=zi+zi'
   xuux=xuux+(1-i/(win+1))*gi
end
 
xpxia = xpxi*xuux*xpxi;
tmp = sqrt(diag(xpxia));
tstat=bet ./ tmp
 
pvalue=ones(nvar,1)
for i=1:nvar
   pvalue(i)=(1-cdft("PQ",abs(tstat(i)),nobs-nvar))*2
end
 
results('x') = x
results('nvar')  = nvar
results('yhat')  = yhat
results('beta')  = bet
results('tstat') = tstat
results('pvalue') = pvalue
results('resid') = resid
results('vcovar') = xpxia
results('sigu') = sigu
 
endfunction
