function []=expbd2exc(grocer_bd,grocer_output,grocer_sep,grocer_transpose,grocer_sepx)
 
// PURPOSE: export the content of a data base or a list of
// variables bd to a file that Excel can read
//-------------------------------------------------------------
// INPUT:
// * grocer_bd = the name of a database or of a list of ts
// loaded in the environment
// * grocer_output = the excel file where to save the data
// * sep = decimal separator (optional: if not given then sep= '.')
// * transpose = a boolean indicating whether the data must be
//   transposed or not (default = %f)
// * grocer_sepx = a string indicating the separator to be used
//   between columns (default ' ')
//-------------------------------------------------------------
// OUTPUT:
// nothing
//-------------------------------------------------------------
// Copyright Eric Dubois 2004-2007
 
// to raise the speed of the function, I make an intensive use
// of the following trick:
//
// for i=1:n
//    y(i)=foo(i)
// end
//
// can be performed also as follows:
//
// execstr('y('+string(1:n)+')=foo('+string(1:n)+')')
// or:
// y=[];execstr('y=[y foo('+string(1:n)+')]')
//
// and this second way is generally more efficient
//
// for instance (line 66):
// execstr('grocer_dmin=[grocer_dmin ; min(datets(grocer_lvar('+string([1:grocer_nvar])+')))]')
//
// is equivalent to:
// for i=1:grocer_nvar
//    grocer_dmin=[grocer_dmin ; min(datets(grocer_lvar(i))]
// end
 
 
if typeof(grocer_bd) ~= 'list' then
   load(grocer_bd)
   grocer_bd=dblist(grocer_bd)
   grocer_nvar=size(grocer_bd,1)
else
   grocer_nvar=length(grocer_bd)
end
 
[nargout,nargin]=argn(0)
if nargin < 5 then
   grocer_sepx=' '
end
if nargin < 4 then
   grocer_transpose=%f
end
if nargin == 2 then
   grocer_sep='.'
end
 
grocer_x=evstr(grocer_bd(1))
select typeof(grocer_x)
case 'ts' then
   grocer_lvar=list()
   execstr('grocer_lvar('+string([1:grocer_nvar])+')=evstr(grocer_bd('+string([1:grocer_nvar])+'))')
   grocer_fq=[]
   grocer_dmin=[]
   grocer_dmax=[]
 
   execstr('grocer_fq=[grocer_fq ; freqts_c(grocer_lvar('+string([1:grocer_nvar])+'))]')
   execstr('grocer_dmin=[grocer_dmin ; min(datets(grocer_lvar('+string([1:grocer_nvar])+')))]')
   execstr('grocer_dmax=[grocer_dmax ; max(datets(grocer_lvar('+string([1:grocer_nvar])+')))]')
   if or(grocer_fq ~= grocer_fq(1)) then
      error('all ts have not the same frequency')
   end
 
   grocer_mindmin=min(grocer_dmin)
   grocer_maxdmax=max(grocer_dmax)
 
   grocer_dat=num2date([grocer_mindmin:grocer_maxdmax],grocer_x('freq'))
   grocer_mat=[['dates' ; grocer_dat'] emptystr(grocer_maxdmax-grocer_mindmin+2,grocer_nvar)+' ']
 
   execstr('grocer_mat(1,'+string(2:grocer_nvar+1)+')=grocer_bd('+string(1:grocer_nvar)+')')
   execstr('grocer_mat([grocer_dmin('+string(1:grocer_nvar)+'):grocer_dmax('+string(1:grocer_nvar)+...
         ')]-grocer_mindmin+2,'+string(2:grocer_nvar+1)+')=string(series(...
         grocer_lvar('+string(1:grocer_nvar)+')))')
 
case 'constant' then
 
   grocer_size_vec=[]
   execstr('grocer_size_vec=[grocer_size_vec ; size(evstr(grocer_bd('+string([1:grocer_nvar])+')),''*'')]')
   grocer_maxs=max(grocer_size_vec)
   grocer_mat=emptystr(grocer_maxs+1,grocer_nvar)
   execstr('grocer_mat(2:1+grocer_size_vec('+string([1:grocer_nvar])+'),'+string([1:grocer_nvar])+...
            ')=string(evstr(grocer_bd('+string([1:grocer_nvar])+')))')
   execstr('grocer_mat(1,'+string([1:grocer_nvar])+')=grocer_bd('+string([1:grocer_nvar])+')')
 
 
else
   error(typeof(grocer_x)+' is not a valid type for the exportation to excel')
end
 
if grocer_sep ~= '.' then
   grocer_mat=strsubst(grocer_mat,'.',grocer_sep)
end
 
if grocer_transpose then
   grocer_mat=grocer_mat'
end
 
grocer_m2tobexported=grocer_mat(:,1)
for grocer_i=2:size(grocer_mat,2)
   grocer_m2tobexported=grocer_m2tobexported+grocer_sepx+grocer_mat(:,grocer_i)
end
 
mputl(grocer_m2tobexported,grocer_output)
 
endfunction
 
