function retal = agregx(retal,c) 

// ------------------------------------------------------------
// fonction permettant la réécriture de la matrice des exogènes LF              
//    selon que l'on accepte ou non une tendance                      
// . retal('trend') = 0 : aucune constante
// . retal('trend') = 1 : modèle avec résidus qui suivent une marche aléatoire + constante 
//                                                ---> modèle en niveau avec trend 
// . retal('trend') = 2 : modèle avec résidus qui suivent un AR(1) + constante 
//                                                ---> modèle avec constante simple
// ------------------------------------------------------------

n = retal('nobs')
s = retal('high freq')
hx = retal('x trim')
N = size(hx,1)

// modèles sans constante
if retal('trend') == 0 then 

    hx_aug = hx
    lx = c*hx

// Modèle en différences avec constante
elseif retal('trend') == 1 then 
   th=s*(s+1)/2+s^2*[1:n+1]
   tl=s+1:N+s
        
   lx = [c*hx th]         
   hx_aug = [hx tl]  

// Modèle avec AR(1) sur les résidus avec constante
else 
    
    lx = [c*hx ones(n,1)] 
    hx_aug = [hx ones(N,1)/s ]     
    // divide by s to obtain the high frequency constant
    
end  

retal(1)($+1) = 'x annu aug'
retal(1)($+1) = 'x trim aug'

retal('x annu aug') = lx 
retal('x trim aug') = hx_aug

endfunction
