function  retal = selecmodel(y,x,s,alpha,mod)  

//--------------------------------------------------------------
// Function that selects the model for the residuals: 
// - an AR(1) on residuals with or without constant
// - a RW on residuals with or without constant
//--------------------------------------------------------------

n =size(y,1)
p = size(x,2)
xc = [x ones(n,1)]

// crate the results tlist 
retal = tlist(['results';'meth';'y estim';'y annu';'x estim';'x annu';'nobs';'resid estim';...
'beta';'tstat';'pvalue';'prescte';'llike';'rho';'trend'],'Insee''s desaggregation')
retal('y annu') = y 
retal('x annu') = x 

if mod == 'no' then 

	// estimation du modèle avec AR(1) sur résidus + test de la constante
	rar1  = olsar(y,xc)
	rar1('prescte') = %t
	pvalue = rar1('pvalue')(p+1)
	if pvalue > alpha then 
		rar1  = olsar(y,x)
	end 

	// estimation du modèle avec marche aléatoire sur résidus + test de la constante	
	if s == 4 then 
		rrw	= olsrw(y,x,1)
	elseif s == 12 
		rrw = olsrw(y,x,2)
	end 
	pvalue = rrw('pvalue')(p+1)
	if pvalue > alpha then 
		rrw  = olsrw(y,x,0)
	end 



	// sélection du modèle 
	if rrw('like') > rar1('like') then 
		rsel = rrw 		
		retal('rho') = 1 
		retal('prescte') = rrw('prescte')

		if retal('prescte') == %t then 
			retal('trend') = 1 
		else 
			retal('trend') = 0
		end 
	else 
		rsel = rar1 
		retal('rho') =  rar1('rho')

		retal('prescte') = rar1('prescte')
		if retal('prescte') == %t then 
			retal('trend') = 2 
		else 
			retal('trend') = 0
		end 
	end 

elseif mod == 'rw' then  
		// estimation du modèle avec marche aléatoire sur résidus + test de la constante	
	if s == 4 then 
		rrw	= olsrw(y,x,1)
	elseif s == 12 
		rrw = olsrw(y,x,2)
	end 
	pvalue = rrw('pvalue')(p+1)
	if pvalue > alpha then 
		rrw  = olsrw(y,x,0)
	end 
	
	retal('prescte') = rrw('prescte')
	if retal('prescte') == %t then 
			retal('trend') = 1 
	else 
			retal('trend') = 0
	end 
	retal('rho') =1 
	rsel = rrw 

elseif mod == 'ar' then 
	// estimation du modèle avec AR(1) sur résidus + test de la constante
	rar1  = olsar(y,xc)
	rar1('prescte') = %t
	pvalue = rar1('pvalue')(p+1)
	if pvalue > alpha then 
		rar1  = olsar(y,x)
	end 
	
	retal('prescte') = rar1('prescte')
	if retal('prescte') == %t then 
		retal('trend') = 2 
	else 
		retal('trend') = 0
	end 
	retal('rho') = rar1('rho')
	rsel = rar1
end 

retal('y estim') = rsel('y')
retal('x estim') = rsel('x')
retal('nobs') = rsel('nobs')
retal('resid estim') = rsel('resid')
retal('beta') = rsel('beta')
retal('tstat') = rsel('tstat')
retal('pvalue') = rsel('pvalue')
retal('prescte') = rsel('prescte')
retal('llike') = rsel('llike')

endfunction
