function f=lfmod_103(theta)
 
// PURPOSE: Computes the exact likelihood function of a general
// State Space model.
// 103 means:
// - the use of the kalman filter (1)
// - the first value of the exogenous variable for the initial
// conditions (econd=3)
// - the estimate of initial values is not made (MV=0)
// ------------------------------------------------------------
// INPUT:
// * theta = (npx1) vector of intial values for the parameters
// * ind = a flag for optim (see optim for details)
// ------------------------------------------------------------
// OUTPUT:
// * f = a scalar, the function value (minus loglikelihood)
// * g = a (npx1) vector, the gradient of the function
// ------------------------------------------------------------
// Copyright Jaime Terceiro, 1997/
// Eric Dubois 2003 for the Scilab translation and adaptation
// http://dubois.ensae.net/grocer.html
 
param=grocer_e4param
m=param.m
T=grocer_e4_T
[Phi,Gam,E,H,D,C,Q,S,R] = theta2ss(theta,grocer_e4_theta2mat);
r = size(Gam,2);
if size(grocer_e4_z,2)~=(m+r) then
  error('Incorrect model');
end
 
[x00,P00] = lfmodini(Phi,Gam,E,H,D,C,Q,S,R,grocer_e4_z,grocer_e4_MV);
[nk1,nx]=size(x00)
nphi=size(P00,2)
CRCt = C*R*C';
ESCt = E*S*C';
EQEt = E*Q*E';
 
f = .5*T*m*log(2*%pi)
np = param.np
g = zeros(np,1);
 
x0= x00;
P0 = P00;
 
z1=zeros(m,T)
 
for t = 1:T
   z1(:,t) = grocer_e4_z(t,1:m)'-H*x0-(D+0)*(grocer_e4_z(t,m+1:m+r)'+0);
   B1 = H*P0*H'+CRCt;
 
   U = cholp(B1,grocer_E4OPTION('scale B')*abs(B1));
   iB1 = eye(m,m)/U/U';
   K1 = (Phi*P0*H'+ESCt)/U/U';
 
   x1 = Phi*x0+(Gam+0)*(grocer_e4_z(t,m+1:m+grocer_e4_r)'+0)+K1*z1(:,t);
   Phib = Phi-K1*H;
   P1 = Phib*P0*Phib'+EQEt+K1*CRCt*K1'-K1*ESCt'-ESCt*K1';
    //
   z1U = z1(:,t)'/U;
 
   f = f+sum(log(diag(U)))+0.5*trace(z1U*z1U');
 
   P0 = P1;
   x0 = x1;
  //
end
// t
 
 
endfunction
