function grocer_H=hessian0(grocer_func4hes,grocer_p,grocer_delta)
 
// PURPOSE: Computes finite symmetric difference Hessian. This
// version uses vectorization and in particular the "nice
// vectorization trick" proposed by Alexander Vignodner
// ------------------------------------------------------------
// INPUT:
// * grocer_func = name of the function
// * grocer_p = point where to evaluate the function
// * grocer_delta = a scalar, the increment used to multiply
//   the absolute values of the parameter
// * vararagin = arguments other than p of funtion func
// ------------------------------------------------------------
// OUTPUT:
// * grocer_H = value of the hessian of func at point p
// ------------------------------------------------------------
// Copyright: Eric Dubois 2006
 
[nargout,nargin]=argn(0)
grocer_n = size(grocer_p,1);
 
// Compute the stepsize (h)
if nargin >=3 then
   grocer_h = grocer_delta*abs(grocer_p)+sqrt(%eps)
else
   grocer_h = %eps^(1/4)*abs(grocer_p)+%eps^(1/4)
end
grocer_ph = grocer_p+grocer_h;
grocer_h = grocer_ph-grocer_p;
grocer_H0=vech(grocer_h*grocer_h');
 
grocer_P=grocer_n*(grocer_n+1)/2
grocer_m1=zeros(grocer_n,grocer_P);
grocer_m2=grocer_m1
grocer_k=0
for grocer_i=1:grocer_n
   hi=grocer_h(grocer_i)
   grocer_m1(grocer_i,grocer_k+grocer_i) = 2*hi ;
   grocer_m1(grocer_i,grocer_k+grocer_i+1:grocer_k+grocer_n) = hi
   grocer_m2(grocer_i,grocer_k+grocer_i+1:grocer_k+grocer_n) = hi
   grocer_dif=grocer_n-grocer_i
   grocer_auxm=eye(grocer_dif,grocer_dif) .* (grocer_h(grocer_i+1:grocer_n) .*. ones(1,grocer_dif))
   grocer_m1(grocer_i+1:grocer_n,grocer_k+grocer_i+1:grocer_k+grocer_n) = grocer_auxm
   grocer_m2(grocer_i+1:grocer_n,grocer_k+grocer_i+1:grocer_k+grocer_n) = -grocer_auxm
   grocer_k=grocer_k+grocer_dif
end
 
grocer_m1=sparse(grocer_m1)
grocer_m2=sparse(grocer_m2)
deff('Hi=grocer_g(grocer_Hx)','Hi=(grocer_func4hes(grocer_p+grocer_m1(:,grocer_Hx))-...
          grocer_func4hes(grocer_p+grocer_m2(:,grocer_Hx))-...
          grocer_func4hes(grocer_p-grocer_m2(:,grocer_Hx))+...
          grocer_func4hes(grocer_p-grocer_m1(:,grocer_Hx)))/grocer_H0(grocer_Hx)/4')
 
grocer_H=[]
 
// here is the trick proposed by Alexander Vigodner:
// when g is a function, instead of doing:
// for i=1:n
//    H=[H ; g(i)]
// end
//
// do:
// execstr('H=[H ; g('+string([1:n]')+')]')

execstr('grocer_H=[grocer_H,grocer_g('+string([1:grocer_P]')+')]')

grocer_H=invvech1(grocer_H',grocer_n)
endfunction
