function [result3]=optim1_d()
 
// PURPOSE: An example using dfp_min, frpr_min, pow_min, maxlik
//
//  to solve a Tobit (censored) regression maximum
//  likelihood problem
 
// generate uncensored data
 
 
n = 200;
k = 5;
rand('seed',20201,'n');
x = rand(n,k,'n');
beta = ones(k,1);
y = x*beta+rand(n,1,'n');
// now censor the data
for i = 1:n
  if y(i,1)<0 then
    y(i,1) = 0;
  end
end
// use ols for starting values
 
res = ols2(y,x);
b = res('beta');
sige = res('sige');
// starting values
parm = [b;sige];
 
deff('[f,g,ind]=cost(a,ind)','f=to_llike(a,y,x),g=numz0(to_llike,a,6,ones(6,1),1e-5,y,x)');
 
// solve using the scilab optim routine
timer();
[f,b1] = optim(cost,parm)
t0=timer()
disp('time taken by the optim routine = '+string(t0))
 
// solve using maxlik routine
result1 = maxlik(to_llike,parm,'maxit=1000',y,x);
t1=timer()
disp('time taken by maxlik routine = '+string(t1))
 
// solve using pow_min routine
result2 = pow_min(to_llike,parm,'maxit=1000',y,x);
t2=timer()
disp('time taken by powell routine = '+string(t2))
 
// solve using frpr_min routine
result3 = frpr_min(to_llike,parm,'maxit=1000',y,x);
t3=timer()
disp('time taken by frpr routine  = '+string(t3))
 
// solve using dfp_min routine
result4 = dfp_min(to_llike,parm,'maxit=1000',y,x);
t4=timer()
disp('time taken by dfp routine = '+string(t4))
 
mat2print=[' ' 'optim' 'maxlik' 'powell' 'frpr' 'dfp' ;...
emptystr(1,6)+' ' ;...
'bhat estimate('+string([1:5]')+')' string([b1(1:5) result1('b')(1:5) result2('b')(1:5) result3('b')(1:5) result4('b')(1:5)]);...
emptystr(1,6)+' ' ;...
'sige estimate' string([b1(6) result1('b')(6) result2('b')(6) result3('b')(6) result4('b')(6)]);...
emptystr(1,6)+' ' ;...
'likelihood estimate' string([f result1('f') result2('f') result3('f') result4('f')]);...
emptystr(1,6)+' ' ;...
'execution time' string([t0 t1 t2 t3 t4])]
 
printmat(mat2print,%io(2))
endfunction
