function []=fan_chart(mat,dat,win,colour,sep)
 
// PURPOSE: draws a fan-chart as the ones used by the Bank of
// England
// ------------------------------------------------------------
// INPUT:
// * mat=a (T x k) probability matrix
// * dat=a (T x 1) vector of dates
// * win=the window's number
// * colour='blue' or 'grey'
// * sep=the decimal separator used for the figures
// ------------------------------------------------------------
// OUPTUT:
// nothing: all results are printed on the graphic window
// ------------------------------------------------------------
// Copyright: Eric Dubois 2008

global GROCERDIR ;
 
[nargout,nargin]=argn(0)
if nargin == 4 then
   sep='.'
end
 
// load the parameters that determines the fonts
load(GROCERDIR+'/param/param_g.dat')
just_scale=%f
 
scf(win)
clf(win)
f=gcf()
 
drawlater()
nbands=size(mat,1)
nx=size(mat,2)
a=gca()
a.data_bounds=[1,min(mat);nx,max(mat)]
half=floor(nbands/2)+1
 
select colour
 
case 'blue' then
   if half >=5 then
      cmap=[0 0 0 ; [0.2 0.3 0.4 linspace(0.5,0.8,half-4)]' .*. ones(1,2) 0.9*ones(half-1,1)]
   else
      cmap=[ 0 0 0 ; [linspace(0.2,0.8,half-1)]' .*. ones(1,2) 0.9*ones(half-1,1)]
   end      
   f.color_map=cmap
   colors=1:half
 
case 'grey'
   xset("colormap",graycolormap(4*nbands))
   colors=[1 3*nbands-floor(5*[half:-1:1]-16)]
end
 
[y0,scale]=drawy(mat,font_axis,[],1,'l',just_scale,0,sep,%t,nx)
nscale=size(scale,2)
 
xset("line style",1)
for i=1:half-2
   xset('color',colors(half-i+1))
   xfpoly([1:nx nx nx:-1:1],[mat(i,:) mat(i+1,$) mat(i+1,$:-1:1)])
   xfpoly([1:nx nx nx:-1:1],[mat(nbands-i+1,:) mat(nbands-i+1,$) mat(nbands-i,$:-1:1)])
end
 
rectc=[1 scale(1) nx scale($)]
// band at the center
xset('color',colors(2))
xfpoly([1:nx nx nx:-1:1],[mat(half-1,:) mat(half-1,$) mat(half+1,$:-1:1)])
 
xset('color',1)
plot2d([1:nx],mat(half,:),axesflag=0,rect=rectc)
g=gca()
gc=g.children(1)
polyl=gc.children
polyl.thickness=5
polyl.line_style=1
 
xset("line style",1)
plot2d([1:nx],scale(nscale)*ones(1,nx),axesflag=0)
g=gca()
gc=g.children(1)
polyl=gc.children
polyl.line_style=1
 
drawx(dat,1,ref_nbinter,font_axis,y0)
//drawy(mat,font_axis,[],nx,'r',just_scale,0,sep)
xset("line style",3)
 
xsegs([1 ; nx] .*. ones(1,nscale-2),[scale(2:$-1) ; scale(2:$-1) ])
xsegs([2:nx-1 ; 2:nx-1],[scale(1)*ones(1,nx-2) ;scale($)*ones(1,nx-2)])
 
drawnow()
 
endfunction
