function prtbma_g(res,out)
 
// PURPOSE: prints the results of a Bayesian Model Averaging
// ------------------------------------------------------------
// OUPTUT:
// nothing: all results are printed on the specified file
// ------------------------------------------------------------
// NOTES:
// used by the following function:
//	bma_g()
// ---------------------------------------------------
// Copyright E. Michaux (2004)
 
[nargout,nargin] = argn(0)
if nargin == 1 then
   out=%io(2)
end
 
write(out,' ')
write(out,' ')
write(out,' ')
write(out,'	Bayesian model averaging estimates')
write(out,' ')
write(out,'dependent variable: '+string(res('namey')))
if res('prests') then
   ch='estimation period: '
   boundsvar=res('bounds')
   for i=1:size(boundsvar,1)/2
      ch=ch+boundsvar(2*i-1)+'-'+boundsvar(2*i)+'  '
   end
   write(out,ch)
end
write(out,'MCMC	 	= '+string(res('mcmc')))
write(out,'# of obs     	= '+string(res('nobs')))
write(out,'# of var     	= '+string(res('nvar')))
write(out,'g-prior	     	= '+string(res('gprior')))
write(out,'# of draws   	= '+string(res('ndraw')))
write(out,'# of burn-in 	= '+string(res('burnin')))
write(out,'# of models  	= '+string(res('nmod')))															
write(out,'max # of var.	= '+string(res('nvmax')))															
write(out,'time (sec.)  	= '+string(res('time')))		
write(out,' ')
write(out,'standard error of the regression: '+string(res('ser')))
write(out,'sum of squared residuals: '+string(res('sigu')))
write(out,' ')
write(out,'	Model averaging information')
write(out,' ')
 
outi = find(res('mprob') > 0.01) //limit printing to models > 1% post prob
nmod = length(outi)
nvar = res('nvar')-1
modor = res('model')(outi,:)'
visor = res('visit')(outi,1)'
mprobor = 100*res('mprob')(outi,1)'
 
cut = 0
if nmod > 21 then
	cut = 3
elseif nmod > 14 & nmod <= 21
	cut = 2
elseif nmod > 7 & nmod <= 14 then
	cut = 1
end
	
 
mod = 'model 1'
for i = 2:nmod
	execstr('mod = [mod,''model '+string(i)+''']')
end
 
matnom = ['models ' ; res('namex')(1:nvar) ; 'prob. (%)' ; 'visits']
 
if cut == 0 then
	matmod= [mod  ; string(modor) ]
	matmod = [matmod ; string(mprobor) ; string(visor)]
	mat2print = [matnom , matmod]
	printmat(mat2print,out)
elseif cut == 1 then
	
	matmod= [mod(1:7)  ; string(modor(:,1:7)) ]
	matmod = [matmod ; string(mprobor(1:7)) ; string(visor(1:7))]
	mat2print = [matnom , matmod]
	printmat(mat2print,out)
	write(out,'')
 
	matmod= [mod(8:nmod)  ; string(modor(:,8:nmod)) ]
	matmod = [matmod ; string(mprobor(8:nmod)) ; string(visor(8:nmod))]
	mat2print = [matnom , matmod]
	printmat(mat2print,out)
 
elseif cut == 2 then
	matmod= [mod(1:7)  ; string(modor(:,1:7)) ]
	matmod = [matmod ; string(mprobor(1:7)) ; string(visor(1:7))]
	mat2print = [matnom , matmod]
	printmat(mat2print,out)
	write(out,'')
	
	matmod= [mod(8:14)  ; string(modor(:,8:14)) ]
	matmod = [matmod ; string(mprobor(8:14)) ; string(visor(8:14))]
	mat2print = [matnom , matmod]
	printmat(mat2print,out)
	write(out,'')
		
	matmod= [mod(15:nmod)  ; string(modor(:,15:nmod)) ]
	matmod = [matmod ; string(mprobor(15:nmod)) ; string(visor(15:nmod))]
	mat2print = [matnom , matmod]
	printmat(mat2print,out)
 
elseif cut == 3 then
	matmod= [mod(1:7)  ; string(modor(:,1:7)) ]
	matmod = [matmod ; string(mprobor(1:7)) ; string(visor(1:7))]
	mat2print = [matnom , matmod]
	printmat(mat2print,out)
	write(out,'')
	
	matmod= [mod(8:14)  ; string(modor(:,8:14)) ]
	matmod = [matmod ; string(mprobor(8:14)) ; string(visor(8:14))]
	mat2print = [matnom , matmod]
	printmat(mat2print,out)
	write(out,'')
		
	matmod= [mod(15:21)  ; string(modor(:,15:21)) ]
	matmod = [matmod ; string(mprobor(15:21)) ; string(visor(15:21))]
	mat2print = [matnom , matmod]
	printmat(mat2print,out)
	
	matmod= [mod(21:nmod)  ; string(modor(:,21:nmod)) ]
	matmod = [matmod ; string(mprobor(21:nmod)) ; string(visor(21:nmod))]
	mat2print = [matnom , matmod]
	printmat(mat2print,out)
 
end
 
write(out,' ')
write(out,'	Posterior Estimates')
write(out,' ')
 
mat2print = [' variable   ',' coeff.  ',' prob. (%)']
mat2print  = [mat2print ; string(res('namex')(1:nvar)) string(res('beta')(1:nvar)) string(100*res('vprob'))]
printmat(mat2print,out)
 
printsep(out)
 
endfunction
