function []=prtres(res,out)
 
// PURPOSE: prints the results of a regression on the file out
// ------------------------------------------------------------
// INPUT:
// * res = the results typed list of a univariate regression
// * out = the symobolic name of the file where the
//              results are printed (default: %io(2))
// ------------------------------------------------------------
// OUPTUT:
// nothing: all results are printed on the specified file
// ------------------------------------------------------------
// NOTES:
// used by the following functions:
// ols(), olsc(), ridge(), automatic()
// ------------------------------------------------------------
// Copyright: Eric Dubois 2002-2009
// http://dubois.ensae.net/grocer.html
 
 
[nargout,nargin] = argn(0)
if nargin == 1 then
   out=%io(2)
end
 
meth=res('meth')
select meth
case 'bkw' then
   plt_dfb(results)
   plt_dff(results)
case 'tvp' then
   prttvp(res)
case 'auto' then
   prtauto(res,list(),out)
case 'johansen' then
   res1=res(1)
   if or(res1 == 'test type') then
      prtjohvec(res,res('nb of cointegration relations'),out)
      prt_johtest(res,out)
   else
      prtjohan(res,out)
   end
case 'varma' then
   prtvarma(res,out)
case 'brybos'
   prtbrybos(res,out)
case 'diebmar' then
   prtdiebmar(res,out)
case 'ms_quali' then
   prtms_quali(res,out)
case 'acp factor' then
   prtfac_pca(res,out)
case 'des_stat' then
   prt_des_stat(res,out)
case 'GMM' then
   prtgmm(res,out)
case 'olsecm' then
   prtuniv(res);
   prtunitr(res);
 
else
 
if or(meth== ['ols';'olst';'olsc';'olsar1';'nls';...
   'iv';'logit';'probit';'tobit';'Theil-Goldberger';...
   'hwhite';'lad';'ridge';'robust';'Newey-West''s HAC';...
   'panel pooled'; 'panel with fixed effects';...
   'panel with random effects';'between';...
   'ordered logit';'ordered probit';'multilogit']) then
// a case would be better, but I have not found how to use
// case with sets of chars
   prtuniv(res,out)
elseif or(meth == ['sur';'twosls';'threesls']) then
   prtsys(res,out)
elseif or(meth == ['var';'bvar';'ecm';'becm']) then
   prtvar(res,out)
elseif or(meth == ['adf';'kpss';'phillips-perron';'Schmidt-Phillips']) then
   prtunitr(res,out)
elseif or(meth == ['archtest';'resular';'predfailin';'white']) then
   prtchi(res,out)
   prtfish(res,out)
elseif or(meth == ['doornhans';'jbnorm';'chowtest';'reset';'predfail';'Ljung-Box';'Box-Pierce']) then
   prtchi(res,out)
elseif or(meth == ['Chow-Lin';'Fernandez';'Litterman']) then
   prtfish(res,out)
elseif or(meth == ['bpagan';'hetero_sq']) then
   prtfish(res,out)
elseif or(meth == ['varf';'varmaf']) then
   prtvarf(res,out)
elseif or(meth == ['ms regression';'ms var';'ms mean']) then
   prtms(res,out)
elseif or(meth == ['BNG panel ur test';'Chang IV';'Choi';'IPS';'Levin-Lin';'Maddala-Wu';'Moon Perron';'Pesaran']) then
   prt_panelur(res,out)
else
   error('sorry, these results are not available for printings with prtres')
end
end
 
endfunction
