function [rnls]=nls(grocer_eq,varargin)
 
// PURPOSE: non linear least-squares regression
// ------------------------------------------------------------
// INPUT:
// * eq = a string representing the equation to estimate
// * varargin =
//   . 'coef=[namecoef1;namecoef2;...;namecoefn]' with
//      namecoefi = name of the coefficient # i in
//     (default coef=['a1';'a2';...;'an'])
//   . 'init=[init1;init2;...;intin] if the user wants to give
//     starting values
//   . any option of maxlik (see maxlik() for a list)
// ------------------------------------------------------------
// OUTPUT:
// rnsls= a tlist with
//   . rnls('meth')  = 'nls'
//   . rnls('beta')  = bhat
//   . rnls('nobs')  = nobs
//   . rnls('nvar')  = nvars
//   . rnls('beta')  = bhat
//   . rnls('resid') = residuals
//   . rnls('vcovar') = estimated variance-covariance matrix of
//                     beta
//   . rnls('sige')  = estimated variance of the residuals
//   . rnls('sigu')  = sum of squared residuals
//   . rnls('ser')  = standard error of the regression
//   . rnls('tstat') = t-stats
//   . rnls('pvalue') = pvalue of the betas
//   . rnls('dw')    = Durbin-Watson Statistic
//   . rnls('prests') = boolean indicating the presence or
//     absence of a time series in the regression
//   . rnls('namey') = the equation
//   . rnls('namex') = name of the coefficients
//   . rnls('bounds') = if there is a timeseries in the
//     regression, the bounds of the regression
//   . rnls('ropt') = the output tlist from maxlik (see maxlik
//                    for the list of arguments)
// ------------------------------------------------------------
// PRINTS: The results of the regression and various diagnostics
// ------------------------------------------------------------
// Copyright: Eric Dubois 2002-2007
 
grocer_nvararg=length(varargin)
grocer_defcoef=%f
grocer_definit=%f
 
for grocer_i=grocer_nvararg:-1:1
   if type(varargin(grocer_i)) == 10 then
      select part(varargin(grocer_i),1:4)
      case 'coef' then
         grocer_coef=str2vec(varargin(grocer_i),',',';')
         grocer_defcoef=%t
         grocer_nvar=size(grocer_coef,1)
         varargin(grocer_i)=null()
      case 'init' then
         execstr('grocer_'+varargin(grocer_i))
         grocer_definit=%t
         varargin(grocer_i)=null()
      end
   end
end
 
grocer_speccarb=['=' ; '+' ; '(' ; '-' ; '*' ; ' ']
if ~grocer_defcoef then
   grocer_ind=[]
   for grocer_i=1:9
      for grocer_k=1:size(grocer_speccarb,1)
         grocer_ind=[grocer_ind strindex(grocer_eq,grocer_speccarb(grocer_k)+'a'+string(grocer_i))]
      end
   end

   grocer_ind=grocer_ind+2   
   grocer_coef=[  ] 

   for grocer_i=1:size(grocer_ind,2)
      grocer_indi=part(grocer_eq,grocer_ind(grocer_i))
      grocer_j=0
      grocer_indc=part(grocer_eq,grocer_ind(grocer_i)+grocer_j)
      while ascii(grocer_indc) >=48 & ascii(grocer_indc) <= 57 
         grocer_j=grocer_j+1
         grocer_indc=part(grocer_eq,grocer_ind(grocer_i)+grocer_j)
      end
      grocer_coef=[grocer_coef ; 'a'+part(grocer_eq,grocer_ind(grocer_i)+[0:grocer_j-1])]
   end
   grocer_coef=unique(grocer_coef) 
   grocer_nvar=size(grocer_coef,1)
end
 
grocer_eqt=grocer_eq
grocer_speccara=['+' ; '-' ; '*' ; '/' ; ')' ; ' ']
for grocer_i=1:grocer_nvar
   for grocer_k=1:size(grocer_speccara,1)
      for grocer_l=1:size(grocer_speccarb,1)
          grocer_eqt=strsubst(grocer_eqt,...
                     grocer_speccarb(grocer_l)+grocer_coef(grocer_i)+...
                     grocer_speccara(grocer_k),grocer_speccarb(grocer_l)+...
                    'grocer_a('+string(grocer_i)+')'+grocer_speccara(grocer_k))
      end
   end
end
 
if grocer_definit then
// the user has provided initial value; check if they are
// a vector and transpose it if necessary
   grocer_init=vec2col(grocer_init)
else
// the user has provided no initial values: they are
// drawn for the normal law
   rand('normal')
   grocer_init=rand(grocer_nvar,1)
end
 
grocer_eqt=strsubst(grocer_eqt,'=','-(')+')'
grocer_a=grocer_init
 
grocer_transeq=evstr(grocer_eqt)
if typeof(grocer_transeq) == 'ts' then
   grocer_prests=%t
// define the range of the series in the ts and, if necessary
// the bounds
   if exists('grocer_boundsvar') == 0 then
      grocer_nls_s=ts2vec(grocer_transeq)
      grocer_d=datets(grocer_transeq)
      grocer_fq=freqts(grocer_transeq)
      grocer_boundsnum='1:grocer_d(size(grocer_d,1))-...
      grocer_d(1)+1'
      grocer_boundsvar=[num2date(grocer_d(1),grocer_fq) ;...
      num2date(grocer_d(size(grocer_d,1)),grocer_fq)]
   elseif isempty(grocer_boundsvar) then
      grocer_nls_s=ts2vec(grocer_transeq)
      grocer_d=datets(grocer_transeq)
      grocer_fq=freqts(grocer_transeq)
      grocer_boundsnum='1:grocer_d(size(grocer_d,1))-...
      grocer_d(1)+1'
      grocer_boundsvar=[num2date(grocer_d(1),grocer_fq) ;...
      num2date(grocer_d(size(grocer_d,1)),grocer_fq)]
   else
      grocer_nls_s=ts2vec(grocer_transeq,grocer_boundsvar)
      grocer_d=datets(grocer_transeq)
      grocer_nper=size(grocer_boundsvar,1)/2
      grocer_d0=grocer_d(1)
      grocer_boundsnum='['
      for grocer_i=1:grocer_nper
         grocer_boundsnum=grocer_boundsnum+string(date2num(...
         grocer_boundsvar(2*grocer_i-1))-grocer_d0+1)+':'...
         +string(date2num(grocer_boundsvar(2*grocer_i))-...
         grocer_d0+1)+' '
      end
      grocer_boundsnum=grocer_boundsnum+']'
   end
   grocer_nobs=size(grocer_nls_s,1)
// define the function to minimize (sum of squared residuals)
// define the function corresponding to the equation
   grocer_chf='deff(''vect=grocer_f(grocer_a)''...
      ,[''transeq=evstr(grocer_eqt)'';...
      ''vect=transeq(''''series'''')('+grocer_boundsnum+')''])'
   execstr(grocer_chf)
else
   grocer_prests=%f
   grocer_nobs=size(grocer_transeq,1)
   grocer_chf='deff(''f=grocer_f(grocer_a)''...
      ,[''f=evstr(grocer_eqt)''])'
   execstr(grocer_chf)
// define the function to minimize (sum of squared residuals)
end

[sigu,bet]=leastsq(grocer_f,grocer_init,varargin(:))
 
// add the usual output (tstat, dw,...)
grad=numz0(grocer_f,bet,grocer_nvar,ones(grocer_nvar,grocer_nobs),sqrt(%eps))
sige=sigu/(grocer_nobs-grocer_nvar)

vcovar=sigu/(grocer_nobs-grocer_nvar)*invxpx(grad')
tmp = sqrt(diag(vcovar));
tstat=bet./tmp
resid = grocer_f(bet)
ediff = resid(2:grocer_nobs)-resid(1:grocer_nobs-1)
dw = ediff'*ediff/sigu
df=grocer_nobs-grocer_nvar
pvalue=[]
for i=1:grocer_nvar
   p=(1-cdft("PQ",abs(tstat(i)),df))*2
   pvalue=[pvalue ; p]
end
 
// store the results
rnls=tlist(['results';'meth';'namey';'namex';'prests';'nobs';...
'nvar';'resid';'ser';'sigu';'sige';'vcovar';'dw';'beta';...
'tstat';'pvalue';'prescte';'dropna'],'nls',grocer_eq,...
grocer_coef,grocer_prests,grocer_nobs,grocer_nvar,resid,...
sqrt(sige),sigu,sige,vcovar,dw,bet,tstat,pvalue,%f,%f)
 
if grocer_prests then
   rnls(1)($+1) = 'bounds'
   rnls('bounds')=grocer_boundsvar
end
 
prtuniv(rnls,%io(2))
endfunction
