function [grocer_p]=statfore(grocer_res,varargin)
 
// PURPOSE: provides a static forecast from an equation
// estimated by ols(), hwhite(), olst(), lad(),...
// ------------------------------------------------------------
// INPUT:
// * res = result tlist
// * varargin  =
//   - (optional) subperiod over which the previson is done if
//   variables are ts
//   - a (mxk) matrix of exogenous variables if they are not ts
// ------------------------------------------------------------
// OUTPUT:
// grocer_p = forecast
// ------------------------------------------------------------
// NOTES:
// * can be used also with results of olsc (but does not take
//   into account the correlation)
// * cannot be used with results of garch (but this needs only
//   small adaptation)
// * if the estimation has been performed with ts, then the
//   function assumes that the variables have been entered
//   between quotes and that their name has therefore been
//   saved in the tlist
// * in that case, the corresponding data must be present in
//   the environment
// ------------------------------------------------------------
// Copyright: Eric Dubois 2002-2008
 
grocer_nargin=length(varargin)
grocer_bet=grocer_res('beta')
if grocer_res('prests') then
   grocer_namex=grocer_res('namex')
// replace the constant term, if any, by 1
   if grocer_namex == 'cte' | grocer_namex == 'const' then
      grocer_arg1=varargin(1)
      if grocer_nargin == 1 then
         if size(grocer_arg1,'*') == 1 then
            cte=reshape(1,grocer_arg1)
         else
            grocer_nper=date2num(grocer_arg1(2))-date2num(grocer_arg1(1))+1
            cte=reshape(ones(grocer_nper,1),grocer_arg1(1))
         end
      else
         grocer_nper=date2num(varargin(2))-date2num(grocer_arg1)+1
         cte=reshape(ones(grocer_nper,1),grocer_arg1)
      end
      const=cte
   else
      grocer_namex(find(grocer_namex=='cte'))='1'
      grocer_namex(find(grocer_namex=='const'))='1'
   end
    
   grocer_p=evstr(grocer_namex(1))*grocer_bet(1)
   for i=2:size(grocer_bet,1)
      grocer_p=grocer_p+evstr(grocer_namex(i))*grocer_bet(i)
   end
   if grocer_nargin ~= 0 then
      grocer_p=subper(grocer_p,varargin(:))
   end
else
   grocer_p=varargin(1)*bet
end
 
endfunction
